@@ -2,6 +2,6 @@
 ## PLOT A REPRESENTATIVE SEQUENCE
 ## ============================================
 
-seqrplot <- function(seqdata, group = NULL, main = NULL, ...) {
+seqrplot <- function(seqdata, group = NULL, main = "auto", ...) {
 	seqplot(seqdata, group=group, type="r", main=main, ...)
 }
